<!--
Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com

This work is licensed under the Creative Commons Attribution-ShareAlike 4.0
International License. To view a copy of this license, visit
http://creativecommons.org/licenses/by-sa/4.0/ or send a letter to Creative
Commons, PO Box 1866, Mountain View, CA 94042, USA.
-->

The developers thank all the open source libraries making
**gemseo-mlearning** possible.

# External Dependencies

**gemseo-mlearning** depends on software with compatible
licenses that are listed below.

[GEMSEO](http://gemseo.org/)
: GNU LGPL v3.0

[Python](http://python.org/)
: Python Software License

# Internal Dependencies

**gemseo-mlearning** source code includes software with
compatible licenses that are listed below.

# External application

Some external applications are used by **gemseo-mlearning**,
but not linked with the application,
for documentation generation,
training or example purposes.

[black](https://black.readthedocs.io)
: MIT

[commitizen](https://commitizen-tools.github.io/commitizen/)
: MIT

[flake8](https://flake8.pycqa.org)
: MIT

[pre-commit](https://pre-commit.com)
: MIT

[pygrep-hooks](https://github.com/pre-commit/pygrep-hooks)
: MIT

[pytest](https://pytest.org)
: MIT

[pytest-cov](https://pytest-cov.readthedocs.io)
: MIT

[pytest-xdist](https://github.com/pytest-dev/pytest-xdist)
: MIT

[reorder-python-imports](https://github.com/asottile/reorder_python_imports)
: MIT

[setuptools](https://setuptools.readthedocs.io/)
: MIT

[setuptools_scm](https://github.com/pypa/setuptools_scm/)
: MIT

# Resources

Some icons and fonts are used by **gemseo-mlearning** or its documentation.
